# =========================#
# Alkalmazott statisztika  #
# 1. ZH                    #
# Gyakorls                #
# =========================#

library(moments)
library(car)

#==================================================================================

# Egy gygyszergyr folykony gygyszer hatkonysgt teszteli, 
# amiket 4 nagy tartlyban kevernek.
# Azonos-e a klnbz tartlyokban lv gygyszerek hatkonysgnak
# vrhat rtke (5%-os szinten)?

adat = read.table("tartalyok.txt", header = TRUE)
attach(adat)

summary(hatekonysag)
tapply(hatekonysag, csoport, mean, na.rm = TRUE)
tapply(hatekonysag, csoport, sd, na.rm = TRUE)
tapply(hatekonysag, csoport, skewness, na.rm = TRUE)
boxplot(hatekonysag ~ csoport)
hist(hatekonysag[csoport == 1])

# Egyszempontos ANOVA
# H0: A vrhat rtkek megegyeznek (mu1 = mu2 = mu3 = mu4)
# HA: nem minden vrhat rtk egyezik meg

# Szignifikancia szint: alpha = 0,05

# Szrsazonossg ellenrzse:
# Levene-teszt
# H0: A variancik mind egyenlk egymssal (sigma1^2 = ... = sigma4^2)
# HA: Nem minden variancia azonos.
leveneTest(hatekonysag ~ factor(csoport), center = mean)
# p = 0,9388 > 0,05 --> elfogadjuk H0-t,
# a variancik azonossgra vonatkoz felttel teljesl

# Variancia analzis:
m1 = aov(hatekonysag ~ factor(csoport))
summary(m1)
# F = 36,82; szabadsgi fokok: 3 s 12; p < 0,001 < 0,05 -->
# elutastjuk a nullhipotzist, a vrhat rtkek kzl legalbb
# kett szignifiknsan klnbzik 5%-os szinten.

detach(adat)

#==================================================================================

# Egy vizsglatban arra voltak kvncsiak, hogy vltozik-e az tlagos reakciid
# hipnzis hatsra. 7 pciens reakciidejt mrtk meg beren s hipnzisban, 
# a kapott eredmnyeket a hipnozis.txt adatbzis tartalmazza.
# Vizsgljuk meg, hogy a reakciid tlagos vltozsa szignifikns-e 5%-os szinten.

adat = read.table("hipnozis.txt", header = TRUE)
attach(adat)

summary(eber)
summary(hipnozis)
kul = eber-hipnozis
summary(kul)
skewness(kul)
boxplot(kul)

# Pros t-prba
# H0: az beren s hipnzisban mrt reakciidk vrhat rtkei megegyeznek (mu1 = mu2)
# HA: a vrhat rtkek klnbzek.

# Szignifikancia szint: alpha = 0,05

t.test(eber, hipnozis, conf.level = 0.95, paired = TRUE)
# t = 3,5277; szabadsgi fok = 6; p = 0,0124
# p < 0,05 --> elutastjuk a nullhipotzist, a vrhat rtkek 5%-os szinten
# szignifiknsan klnbznek.

detach(adat)

#==================================================================================

# A szokincs.txt adatbzis egy szkincs-felmr teszten elrt pontszmokat tartalmazza, 
# 20 vesek (csoport = 1) s 60 vesek (csoport = 2) esetn. 
# Van-e szignifikns klnbsg a kt csoport vrhat rtke kztt 5%-os szinten?

adat = read.table("szokincs.txt", header = TRUE)
csop = with(adat, factor(csop, levels = c(1,2), labels = c("20 ves", "60 ves")))
attach(adat)
summary(szokincs)
tapply(szokincs, csop, mean, na.rm = TRUE)
tapply(szokincs, csop, sd, na.rm = TRUE)
tapply(szokincs, csop, skewness, na.rm = TRUE)
boxplot(szokincs ~ csop)

# Ktmints t-prba
# H0: A kt csoport pontszmainak vrhat rtke azonos (mu1 = mu2).
# HA: A kt csoport pontszmainak vrhat rtke klnbz.

# Szignifikancia szint: alpha = 0,05

# Szrsazonossg ellenrzse F-prbval:
var.test(szokincs[csop == "20 ves"], szokincs[csop == "60 ves"])
# H0: A kt csoport pontszmainak variancija megegyezik.
# p = 0,8605 > 0,05 --> felttelezhetjk a variancik azonossgt.

# Ktmints t-prba:
t.test(szokincs[csop == "20 ves"], szokincs[csop == "60 ves"], var.equal = TRUE)
# t = -3,4229; szabadsgi fok = 15; p = 0,003776
# p < 0,05 --> elutastjuk H0-t, a 20 vesek s a 60 vesek tlagos pontszma
# szignifiknsan klnbz 5%-os szinten.

detach(adat)

#==================================================================================

# Az orvkerd.csv adatbzis elsves orvostanhallgatk krdves felmrsnek
# eredmnyt tartalmazza. Vizsgljuk meg 5%-os szignifikancia szinten azt a 
# nullhipotzist, hogy a "tomeg" vltoz normlis eloszlst kvet. Adjunk 
# 99% megbzhatsgi szint konfidenciaintervallumot a testtmegek vrhat rtkre.

adat = read.table("orvkerd.txt",header = TRUE)
attach(adat)

# Normalitsvizsglat:
# Egymints Kolmogorov-Szmirnov-prba
# H0: A "tomeg" vltoz normlis eloszlst kvet.
# HA: A "tmeg" vltoz nem normlis eloszlst kvet.
# Szignifikancia szint: alpha = 0,05
ks.test(tomeg, "pnorm", mean(tomeg), sd(tomeg))
# p = 0,1952 > 0,05 --> nem tudjuk elutastani a nullhipotzist,
# felttelezhetjk a testtmegek normalitst.

# Konfidencia intervallum:
# Szignfikancia szint: alpha = 0,01 (megbzhatsgi szint = 0,99)
t.test(tomeg, conf.level = 0.99)$conf.int

detach(adat)

#==================================================================================

# James Bond szerint a martini jobb rzva, mint keverve. Azt szeretnnk tesztelni, 
# hogy tnyleg tud-e klnbsget tenni a ktfle elksztsi md kztt. 
# 16 pohr martini mindegyikrl el kell dntenie, hogy rzva vagy keverve kszlt.
# A 16 esetbl 13-szor helyesen dnt. Vajon csak tallgatott? 

# Binomilis prba
# H0: James Bond tallgatott (p = 0,5)
# HA: p != 0,5

# Szignifikancia szint: alpha = 0,05

binom.test(x = 13, n = 16, p = 0.5)
# p = 0,02127 < 0,05 --> Elutastjuk a nullhipotzist, James Bond tnyleg tud 
# klnbsget tenni a rzva s a keverve kszlt martini kztt.

